#include "EntryType.hpp"
#include "LogEntry.hpp"
#include "XmlLogWriter.hpp"

#include <QString>
#include <QXmlStreamWriter>

ExtendedLog::XmlLogWriter::XmlLogWriter(QString filename) :
	inputFile(filename),
	xmlWriter(&inputFile)
{
	if (!inputFile.open(QIODevice::ReadWrite)) { throw false; }
	xmlWriter.setAutoFormatting(true);
	xmlWriter.setCodec("UTF-8");
	xmlWriter.writeStartDocument();
}

void ExtendedLog::XmlLogWriter::writeEntry(EntryType type, QString message)
{
	LogEntry entry(type, message);
	xmlWriter.writeStartElement("entry");

	xmlWriter.writeStartElement("datetime");
	xmlWriter.writeCharacters(entry.getDateTime().toString("dd.MM.yyyy hh:mm:ss"));
	xmlWriter.writeEndElement();

	xmlWriter.writeStartElement("type");
	xmlWriter.writeCharacters(entry.typeString());
	xmlWriter.writeEndElement();

	xmlWriter.writeStartElement("message");
	xmlWriter.writeCharacters(entry.getMessage());
	xmlWriter.writeEndElement();

	xmlWriter.writeEndElement();
}

void ExtendedLog::XmlLogWriter::close()
{
	xmlWriter.writeEndDocument();
	inputFile.close();
}
